Type

Struct Type 

pub struct Type<'t>(/* private fields */);
Represents a type from the type table. A Type has been minimally processed and may not be correctly formed or even understood by this library.

To avoid copying, Types exist as references to data owned by the parent TypeInformation. Therefore, a Type may not outlive its parent.

Implementations

Source

impl<'t> Type<'t>

pub fn type_index(&self) -> TypeIndex

Returns this type’s TypeIndex.

pub fn len(&self) -> usize

Returns the length of this type’s data in terms of bytes in the on-disk format.

Types are prefixed by length, which is not included in this count.

pub fn raw_kind(&self) -> u16

Returns the kind of type identified by this Type.

As a special case, if this Type is actually a primitive type, raw_kind() will return 0xffff.

pub fn parse(&self) -> Result<TypeData<'t>>

Parse this Type into a TypeData.

Errors
  • Error::UnimplementedTypeKind(kind) if the type record isn’t currently understood by this library
  • Error::UnexpectedEof if the type record is malformed