pub struct Type<'t>(/* private fields */);Expand description
Represents a type from the type table. A Type has been minimally processed and may not be
correctly formed or even understood by this library.
To avoid copying, Types exist as references to data owned by the parent TypeInformation.
Therefore, a Type may not outlive its parent.
Implementations
Sourceimpl<'t> Type<'t>
impl<'t> Type<'t>
Sourcepub fn type_index(&self) -> TypeIndex
pub fn type_index(&self) -> TypeIndex
Returns this type’s TypeIndex.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the length of this type’s data in terms of bytes in the on-disk format.
Types are prefixed by length, which is not included in this count.