pub struct TypeIter<'t> { /* private fields */ }Expand description
A TypeIter iterates over a TypeInformation, producing Typess.
Type streams are represented internally as a series of records, each of which have a length, a type, and a type-specific field layout. Iteration performance is therefore similar to a linked list.